@@ -47,6 +47,7 @@ debug = 0
 
 # Variables - Change version
 arch_type = ''
+pre_value = ''
 # Variables - Change version
 
 # Variables - Sync repository
@@ -88,6 +89,7 @@ def main(argv):
     # Variables - Change version
     global arch_type
     global change_type
+    global pre_value
     # Variables - Change version
     
     global branch
@@ -100,8 +102,8 @@ def main(argv):
         opts, args = getopt.getopt(argv, "a:b:c:d:h:f:m:n:u:p:r:g:t:w:", ["command=", "help=", 
                                                 "artifactname=", "repository=","groupid=", "directory=", "nexushost=",
                                                 "file=", "awxhost=",
-                                                "--format=",
-                                                "type=", "archtype=",
+                                                "format=",
+                                                "type=", "archtype=", "prevalue=",
                                                 "message=", "branch=",
                                                 "debug"
                                                ])
@@ -165,6 +167,7 @@ def main(argv):
                 print("e.g --archtype npm, gradle, maven, flutter, dotnet, netcore")
                 print("\nOptional arguments: ")
                 print("-b, --branch        Branch to commit code changes. Default: develop")
+                print("--preValue          Prerelease version value e.g SNAPHOT, RELEASE, BUILD, beta, alpa")
                
                 return sys.exit(0)
             elif arg == 'create':
@@ -186,10 +189,10 @@ def main(argv):
             if action == '':
                 print("Invalid command specified")
                 return sys.exit(2)
-        elif opt == "proxy":
+        elif opt == "--proxy":
             proxies['http'] = arg
         
-        elif opt == "proxysec":
+        elif opt == "--proxysec":
             proxies['https'] = arg    
             
         ## Deploy-artifact-awx-host params START
@@ -221,7 +224,10 @@ def main(argv):
             change_type = arg
             
         elif opt in ("-a", "--archtype"):
-            arch_type = arg      
+            arch_type = arg 
+            
+        elif opt == "--prevalue":
+            pre_value = arg     
             
          ## Change-version-number params END
         
